import sys

from PyQt4 import QtGui,  QtCore
from PyQt4.QtCore import QDir, Qt, QFileInfo, QTimer
from PyQt4.QtGui import QSplitter


class FileBrowser(QSplitter):
    def __init__(self, parent = None):
        super(FileBrowser, self).__init__(parent)

        self.setOrientation(Qt.Horizontal)

        # Directory tree and model
        self.__treeView = QtGui.QTreeView()
        self.__treeView.setSortingEnabled (True)
        self.__dirModel = QtGui.QFileSystemModel()
        self.__dirModel.setFilter(QDir.AllDirs | QDir.NoDotAndDotDot)
        # Path
        rootindex = self.__dirModel.setRootPath(QDir.rootPath())
        homeindex = self.__dirModel.index(QDir.homePath())
        self.__treeView.setModel(self.__dirModel)
        self.__treeView.setRootIndex(rootindex)
        self.__treeView.scrollTo(homeindex,  QtGui.QAbstractItemView.PositionAtTop)
        self.__treeView.expand(homeindex)
        self.__treeView.sortByColumn(0, Qt.AscendingOrder)
        self.__treeView.setAlternatingRowColors(True)
        self.__treeView.setAnimated(True)
        self.__treeView.hideColumn(1)
        self.__treeView.hideColumn(2)

        # File tree and model
        self.__fileModel = QtGui.QFileSystemModel()
        #self.__fileModel.setFilter(QDir.Files)
        self.__fileView = QtGui.QTreeView()
        self.__fileView.setModel(self.__fileModel)
        # Path
        self.__fileModel.setRootPath(QDir.rootPath())
        homeindex = self.__fileModel.index(QDir.homePath())
        self.__fileView.setRootIndex(homeindex)
        self.__fileView.setSortingEnabled (True)
        self.__fileView.sortByColumn(2, Qt.AscendingOrder)
        self.__fileView.setAlternatingRowColors(True)
        self.__fileView.setAnimated(True)
        self.__fileView.setSelectionMode(QtGui.QAbstractItemView.MultiSelection)
        QTimer.singleShot(200, self.resizeColumn)

        # Splitter layout
        self.addWidget(self.__treeView)
        self.addWidget(self.__fileView)

        # Signals
        self.__treeView.clicked.connect(self.updateFiles)
        self.__treeView.expanded.connect(self.updateFiles)
        self.__fileView.clicked.connect(self.resizeColumn)
        self.__fileView.expanded.connect(self.resizeColumn)
        self.__fileView.selectionModel().selectionChanged.connect(self.updateSelection)


    @QtCore.pyqtSlot('QModelIndex')
    def updateFiles(self,  index):
        path = self.__dirModel.filePath(index)
        fileIndex = self.__fileModel.index(path)
        self.__fileView.setRootIndex(fileIndex)
        QTimer.singleShot(400, self.resizeColumn)


    @QtCore.pyqtSlot()
    def updateSelection(self):
        list = self.__fileView.selectionModel().selectedIndexes()
        row = -1
        for index in list:
            if index.row() != row and index.column() == 0:
                fileInfo = QFileInfo(self.__fileModel.fileInfo(index))
                print fileInfo.fileName(),
                row = index.row()
        print


    def resizeColumn(self):
        self.__treeView.resizeColumnToContents(0)
        self.__fileView.resizeColumnToContents(0)

if __name__ == '__main__':
    app = QtGui.QApplication(sys.argv)
    MainWindowClass = QtGui.QMainWindow()
    fileb = FileBrowser()
    fileb.resize(1000, 600)
    fileb.show()
    sys.exit(app.exec_())
